# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.agent import create_compute_instance_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2
from yandex.cloud.loadtesting.api.v1.agent import agent_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/api/v1/agent_service.proto',
  package='yandex.cloud.loadtesting.api.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3yandex/cloud/loadtesting/api/v1/agent_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x43yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto\x1a\x31yandex/cloud/loadtesting/api/v1/agent/agent.proto\x1a\x1dyandex/cloud/validation.proto\"\xfc\x01\n\x12\x43reateAgentRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12]\n\x17\x63ompute_instance_params\x18\x04 \x01(\x0b\x32<.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance\x12\x15\n\ragent_version\x18\x05 \x01(\t\"\'\n\x13\x43reateAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"#\n\x0fGetAgentRequest\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\"&\n\x12\x44\x65leteAgentRequest\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"\'\n\x13\x44\x65leteAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t2\x94\x04\n\x0c\x41gentService\x12\xac\x01\n\x06\x43reate\x12\x33.yandex.cloud.loadtesting.api.v1.CreateAgentRequest\x1a!.yandex.cloud.operation.Operation\"J\x82\xd3\xe4\x93\x02\x1e\"\x19/loadtesting/api/v1/agent:\x01*\xb2\xd2*\"\n\x13\x43reateAgentMetadata\x12\x0b\x61gent.Agent\x12\x93\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.api.v1.GetAgentRequest\x1a,.yandex.cloud.loadtesting.api.v1.agent.Agent\",\x82\xd3\xe4\x93\x02&\x12$/loadtesting/api/v1/agent/{agent_id}\x12\xbe\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.loadtesting.api.v1.DeleteAgentRequest\x1a!.yandex.cloud.operation.Operation\"\\\x82\xd3\xe4\x93\x02&*$/loadtesting/api/v1/agent/{agent_id}\xb2\xd2*,\n\x13\x44\x65leteAgentMetadata\x12\x15google.protobuf.EmptyBv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_CREATEAGENTREQUEST = _descriptor.Descriptor(
  name='CreateAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute_instance_params', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.compute_instance_params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentRequest.agent_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=344,
  serialized_end=596,
)


_CREATEAGENTMETADATA = _descriptor.Descriptor(
  name='CreateAgentMetadata',
  full_name='yandex.cloud.loadtesting.api.v1.CreateAgentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.CreateAgentMetadata.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=637,
)


_GETAGENTREQUEST = _descriptor.Descriptor(
  name='GetAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.GetAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.GetAgentRequest.agent_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=674,
)


_DELETEAGENTREQUEST = _descriptor.Descriptor(
  name='DeleteAgentRequest',
  full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentRequest.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=714,
)


_DELETEAGENTMETADATA = _descriptor.Descriptor(
  name='DeleteAgentMetadata',
  full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agent_id', full_name='yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata.agent_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=755,
)

_CREATEAGENTREQUEST.fields_by_name['compute_instance_params'].message_type = yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2._CREATECOMPUTEINSTANCE
DESCRIPTOR.message_types_by_name['CreateAgentRequest'] = _CREATEAGENTREQUEST
DESCRIPTOR.message_types_by_name['CreateAgentMetadata'] = _CREATEAGENTMETADATA
DESCRIPTOR.message_types_by_name['GetAgentRequest'] = _GETAGENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAgentRequest'] = _DELETEAGENTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAgentMetadata'] = _DELETEAGENTMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAgentRequest = _reflection.GeneratedProtocolMessageType('CreateAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.CreateAgentRequest)
  })
_sym_db.RegisterMessage(CreateAgentRequest)

CreateAgentMetadata = _reflection.GeneratedProtocolMessageType('CreateAgentMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAGENTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.CreateAgentMetadata)
  })
_sym_db.RegisterMessage(CreateAgentMetadata)

GetAgentRequest = _reflection.GeneratedProtocolMessageType('GetAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.GetAgentRequest)
  })
_sym_db.RegisterMessage(GetAgentRequest)

DeleteAgentRequest = _reflection.GeneratedProtocolMessageType('DeleteAgentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAGENTREQUEST,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.DeleteAgentRequest)
  })
_sym_db.RegisterMessage(DeleteAgentRequest)

DeleteAgentMetadata = _reflection.GeneratedProtocolMessageType('DeleteAgentMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAGENTMETADATA,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.DeleteAgentMetadata)
  })
_sym_db.RegisterMessage(DeleteAgentMetadata)


DESCRIPTOR._options = None
_CREATEAGENTREQUEST.fields_by_name['folder_id']._options = None
_CREATEAGENTREQUEST.fields_by_name['name']._options = None
_CREATEAGENTREQUEST.fields_by_name['description']._options = None

_AGENTSERVICE = _descriptor.ServiceDescriptor(
  name='AgentService',
  full_name='yandex.cloud.loadtesting.api.v1.AgentService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=758,
  serialized_end=1290,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\036\"\031/loadtesting/api/v1/agent:\001*\262\322*\"\n\023CreateAgentMetadata\022\013agent.Agent',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Get',
    index=1,
    containing_service=None,
    input_type=_GETAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2._AGENT,
    serialized_options=b'\202\323\344\223\002&\022$/loadtesting/api/v1/agent/{agent_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.loadtesting.api.v1.AgentService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETEAGENTREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&*$/loadtesting/api/v1/agent/{agent_id}\262\322*,\n\023DeleteAgentMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AGENTSERVICE)

DESCRIPTOR.services_by_name['AgentService'] = _AGENTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/v1/template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/marketplace/licensemanager/v1/template.proto',
  package='yandex.cloud.marketplace.licensemanager.v1',
  syntax='proto3',
  serialized_options=b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9yandex/cloud/marketplace/licensemanager/v1/template.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x03\n\x08Template\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0cpublisher_id\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\x12\x11\n\ttariff_id\x18\x06 \x01(\t\x12\x16\n\x0elicense_sku_id\x18\x07 \x01(\t\x12\x0e\n\x06period\x18\x08 \x01(\t\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x05state\x18\x0b \x01(\x0e\x32:.yandex.cloud.marketplace.licensemanager.v1.Template.State\"T\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0e\n\nDEPRECATED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\x42\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_TEMPLATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='yandex.cloud.marketplace.licensemanager.v1.Template.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPRECATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=469,
  serialized_end=553,
)
_sym_db.RegisterEnumDescriptor(_TEMPLATE_STATE)


_TEMPLATE = _descriptor.Descriptor(
  name='Template',
  full_name='yandex.cloud.marketplace.licensemanager.v1.Template',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.version_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publisher_id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.publisher_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.product_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tariff_id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.tariff_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license_sku_id', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.license_sku_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.period', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.created_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.updated_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='yandex.cloud.marketplace.licensemanager.v1.Template.state', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEMPLATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=553,
)

_TEMPLATE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEMPLATE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEMPLATE.fields_by_name['state'].enum_type = _TEMPLATE_STATE
_TEMPLATE_STATE.containing_type = _TEMPLATE
DESCRIPTOR.message_types_by_name['Template'] = _TEMPLATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Template = _reflection.GeneratedProtocolMessageType('Template', (_message.Message,), {
  'DESCRIPTOR' : _TEMPLATE,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.template_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.Template)
  })
_sym_db.RegisterMessage(Template)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/agent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.agent import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/api/v1/agent/agent.proto',
  package='yandex.cloud.loadtesting.api.v1.agent',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/loadtesting/api/v1/agent/agent.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a\x32yandex/cloud/loadtesting/api/v1/agent/status.proto\"\xcd\x01\n\x05\x41gent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x05 \x01(\t\x12=\n\x06status\x18\x07 \x01(\x0e\x32-.yandex.cloud.loadtesting.api.v1.agent.Status\x12\x0e\n\x06\x65rrors\x18\x08 \x03(\t\x12\x16\n\x0e\x63urrent_job_id\x18\t \x01(\tB|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_status__pb2.DESCRIPTOR,])




_AGENT = _descriptor.Descriptor(
  name='Agent',
  full_name='yandex.cloud.loadtesting.api.v1.agent.Agent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute_instance_id', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.compute_instance_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.status', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.errors', index=6,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_job_id', full_name='yandex.cloud.loadtesting.api.v1.agent.Agent.current_job_id', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=350,
)

_AGENT.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['Agent'] = _AGENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Agent = _reflection.GeneratedProtocolMessageType('Agent', (_message.Message,), {
  'DESCRIPTOR' : _AGENT,
  '__module__' : 'yandex.cloud.loadtesting.api.v1.agent.agent_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.loadtesting.api.v1.agent.Agent)
  })
_sym_db.RegisterMessage(Agent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/loadtesting/api/v1/agent/status.proto',
  package='yandex.cloud.loadtesting.api.v1.agent',
  syntax='proto3',
  serialized_options=b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2yandex/cloud/loadtesting/api/v1/agent/status.proto\x12%yandex.cloud.loadtesting.api.v1.agent*\xbb\x02\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0ePREPARING_TEST\x10\x01\x12\x12\n\x0eREADY_FOR_TEST\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0f\n\x0bTANK_FAILED\x10\x04\x12\x10\n\x0cPROVISIONING\x10\x05\x12\x0c\n\x08STOPPING\x10\x06\x12\x0b\n\x07STOPPED\x10\x07\x12\x0c\n\x08STARTING\x10\x08\x12\x0e\n\nRESTARTING\x10\t\x12\x0c\n\x08UPDATING\x10\n\x12\t\n\x05\x45RROR\x10\x0b\x12\x0b\n\x07\x43RASHED\x10\x0c\x12\x0c\n\x08\x44\x45LETING\x10\r\x12\x1b\n\x17INITIALIZING_CONNECTION\x10\x0f\x12\x1e\n\x1aLOST_CONNECTION_WITH_AGENT\x10\x10\x12\x17\n\x13UPLOADING_ARTIFACTS\x10\x11\x42|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3'
)

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.loadtesting.api.v1.agent.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING_TEST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY_FOR_TEST', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TESTING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TANK_FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROVISIONING', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPING', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTING', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTARTING', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATING', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRASHED', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INITIALIZING_CONNECTION', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOST_CONNECTION_WITH_AGENT', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADING_ARTIFACTS', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=94,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
STATUS_UNSPECIFIED = 0
PREPARING_TEST = 1
READY_FOR_TEST = 2
TESTING = 3
TANK_FAILED = 4
PROVISIONING = 5
STOPPING = 6
STOPPED = 7
STARTING = 8
RESTARTING = 9
UPDATING = 10
ERROR = 11
CRASHED = 12
DELETING = 13
INITIALIZING_CONNECTION = 15
LOST_CONNECTION_WITH_AGENT = 16
UPLOADING_ARTIFACTS = 17


DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/v1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.marketplace.licensemanager.v1 import instance_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/marketplace/licensemanager/v1/instance_service.proto',
  package='yandex.cloud.marketplace.licensemanager.v1',
  syntax='proto3',
  serialized_options=b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAyandex/cloud/marketplace/licensemanager/v1/instance_service.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x39yandex/cloud/marketplace/licensemanager/v1/instance.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x12GetInstanceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xa6\x01\n\x14ListInstancesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"y\n\x15ListInstancesResponse\x12G\n\tinstances\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.marketplace.licensemanager.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x91\x03\n\x0fInstanceService\x12\xbc\x01\n\x03Get\x12>.yandex.cloud.marketplace.licensemanager.v1.GetInstanceRequest\x1a\x34.yandex.cloud.marketplace.licensemanager.v1.Instance\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/marketplace/license-manager/v1/instances/{instance_id}\x12\xbe\x01\n\x04List\x12@.yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest\x1a\x41.yandex.cloud.marketplace.licensemanager.v1.ListInstancesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/marketplace/license-manager/v1/instancesB\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.marketplace.licensemanager.v1.GetInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=233,
  serialized_end=280,
)


_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=449,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.marketplace.licensemanager.v1.ListInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=572,
)

_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2._INSTANCE
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.GetInstanceRequest)
  })
_sym_db.RegisterMessage(GetInstanceRequest)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.ListInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.marketplace.licensemanager.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.marketplace.licensemanager.v1.ListInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstancesResponse)


DESCRIPTOR._options = None
_GETINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_LISTINSTANCESREQUEST.fields_by_name['folder_id']._options = None
_LISTINSTANCESREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCESREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCESREQUEST.fields_by_name['filter']._options = None
_LISTINSTANCESREQUEST.fields_by_name['order_by']._options = None

_INSTANCESERVICE = _descriptor.ServiceDescriptor(
  name='InstanceService',
  full_name='yandex.cloud.marketplace.licensemanager.v1.InstanceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=575,
  serialized_end=976,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.marketplace.licensemanager.v1.InstanceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_instance__pb2._INSTANCE,
    serialized_options=b'\202\323\344\223\0029\0227/marketplace/license-manager/v1/instances/{instance_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.marketplace.licensemanager.v1.InstanceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\002+\022)/marketplace/license-manager/v1/instances',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESERVICE)

DESCRIPTOR.services_by_name['InstanceService'] = _INSTANCESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.kms.v1.asymmetricencryption import asymmetric_encryption_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto',
  package='yandex.cloud.kms.v1.asymmetricencryption',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nPyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key_service.proto\x12(yandex.cloud.kms.v1.asymmetricencryption\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1aHyandex/cloud/kms/v1/asymmetricencryption/asymmetric_encryption_key.proto\"\xe2\x03\n$CreateAsymmetricEncryptionKeyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\xab\x01\n\x06labels\x18\x04 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x65\n\x14\x65ncryption_algorithm\x18\x05 \x01(\x0e\x32G.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%CreateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"A\n!GetAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x84\x01\n#ListAsymmetricEncryptionKeysRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x90\x01\n$ListAsymmetricEncryptionKeysResponse\x12O\n\x04keys\x18\x01 \x03(\x0b\x32\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x04\n$UpdateAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12X\n\x06status\x18\x05 \x01(\x0e\x32H.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey.Status\x12\xab\x01\n\x06labels\x18\x06 \x03(\x0b\x32Z.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04<=63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"D\n$DeleteAsymmetricEncryptionKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x8a\x01\n,ListAsymmetricEncryptionKeyOperationsRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x7f\n-ListAsymmetricEncryptionKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd0\x10\n\x1e\x41symmetricEncryptionKeyService\x12\xec\x01\n\x06\x43reate\x12N.yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02%\" /kms/v1/asymmetricEncryptionKeys:\x01*\xb2\xd2*@\n%CreateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xc8\x01\n\x03Get\x12K.yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest\x1a\x41.yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKey\"1\x82\xd3\xe4\x93\x02+\x12)/kms/v1/asymmetricEncryptionKeys/{key_id}\x12\xcf\x01\n\x04List\x12M.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest\x1aN.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /kms/v1/asymmetricEncryptionKeys\x12\xf5\x01\n\x06Update\x12N.yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"x\x82\xd3\xe4\x93\x02.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\x01*\xb2\xd2*@\n%UpdateAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xf2\x01\n\x06\x44\x65lete\x12N.yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest\x1a!.yandex.cloud.operation.Operation\"u\x82\xd3\xe4\x93\x02+*)/kms/v1/asymmetricEncryptionKeys/{key_id}\xb2\xd2*@\n%DeleteAsymmetricEncryptionKeyMetadata\x12\x17\x41symmetricEncryptionKey\x12\xff\x01\n\x0eListOperations\x12V.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest\x1aW.yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/kms/v1/asymmetricEncryptionKeys/{key_id}/operations\x12\xc0\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings\x12\xf0\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x88\x01\x82\xd3\xe4\x93\x02\x45\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xfc\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\x82\xd3\xe4\x93\x02H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBk\n\x17yandex.cloud.api.kms.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricencryption;kmsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2.DESCRIPTOR,])




_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=886,
)

_CREATEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='CreateAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encryption_algorithm', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.encryption_algorithm', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.deletion_protection', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=886,
)


_CREATEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='CreateAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=943,
)


_GETASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='GetAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=945,
  serialized_end=1010,
)


_LISTASYMMETRICENCRYPTIONKEYSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeysRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1145,
)


_LISTASYMMETRICENCRYPTIONKEYSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeysResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse.keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1292,
)


_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=886,
)

_UPDATEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='UpdateAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1024', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\004<=63\262\3101\022\022\020[a-z][-_0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.deletion_protection', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1295,
  serialized_end=1816,
)


_UPDATEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='UpdateAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=1873,
)


_DELETEASYMMETRICENCRYPTIONKEYREQUEST = _descriptor.Descriptor(
  name='DeleteAsymmetricEncryptionKeyRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1875,
  serialized_end=1943,
)


_DELETEASYMMETRICENCRYPTIONKEYMETADATA = _descriptor.Descriptor(
  name='DeleteAsymmetricEncryptionKeyMetadata',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1945,
  serialized_end=2000,
)


_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeyOperationsRequest',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_id', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2141,
)


_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListAsymmetricEncryptionKeyOperationsResponse',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2143,
  serialized_end=2270,
)

_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY.containing_type = _CREATEASYMMETRICENCRYPTIONKEYREQUEST
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels'].message_type = _CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['encryption_algorithm'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONALGORITHM
_LISTASYMMETRICENCRYPTIONKEYSRESPONSE.fields_by_name['keys'].message_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY.containing_type = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['status'].enum_type = yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY_STATUS
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels'].message_type = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['CreateAsymmetricEncryptionKeyRequest'] = _CREATEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateAsymmetricEncryptionKeyMetadata'] = _CREATEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['GetAsymmetricEncryptionKeyRequest'] = _GETASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeysRequest'] = _LISTASYMMETRICENCRYPTIONKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeysResponse'] = _LISTASYMMETRICENCRYPTIONKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAsymmetricEncryptionKeyRequest'] = _UPDATEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateAsymmetricEncryptionKeyMetadata'] = _UPDATEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteAsymmetricEncryptionKeyRequest'] = _DELETEASYMMETRICENCRYPTIONKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAsymmetricEncryptionKeyMetadata'] = _DELETEASYMMETRICENCRYPTIONKEYMETADATA
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeyOperationsRequest'] = _LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListAsymmetricEncryptionKeyOperationsResponse'] = _LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('CreateAsymmetricEncryptionKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyRequest)
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyRequest.LabelsEntry)

CreateAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('CreateAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.CreateAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(CreateAsymmetricEncryptionKeyMetadata)

GetAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('GetAsymmetricEncryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.GetAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(GetAsymmetricEncryptionKeyRequest)

ListAsymmetricEncryptionKeysRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeysRequest)

ListAsymmetricEncryptionKeysResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeysResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeysResponse)

UpdateAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricEncryptionKeyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyRequest)
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyRequest.LabelsEntry)

UpdateAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.UpdateAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateAsymmetricEncryptionKeyMetadata)

DeleteAsymmetricEncryptionKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricEncryptionKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICENCRYPTIONKEYREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyRequest)
  })
_sym_db.RegisterMessage(DeleteAsymmetricEncryptionKeyRequest)

DeleteAsymmetricEncryptionKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteAsymmetricEncryptionKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEASYMMETRICENCRYPTIONKEYMETADATA,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.DeleteAsymmetricEncryptionKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteAsymmetricEncryptionKeyMetadata)

ListAsymmetricEncryptionKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeyOperationsRequest)

ListAsymmetricEncryptionKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListAsymmetricEncryptionKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricencryption.asymmetric_encryption_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricencryption.ListAsymmetricEncryptionKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListAsymmetricEncryptionKeyOperationsResponse)


DESCRIPTOR._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['folder_id']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['name']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['description']._options = None
_CREATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels']._options = None
_GETASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['folder_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICENCRYPTIONKEYSREQUEST.fields_by_name['page_token']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST_LABELSENTRY._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['update_mask']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['name']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['description']._options = None
_UPDATEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['labels']._options = None
_DELETEASYMMETRICENCRYPTIONKEYREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['key_id']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_ASYMMETRICENCRYPTIONKEYSERVICE = _descriptor.ServiceDescriptor(
  name='AsymmetricEncryptionKeyService',
  full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2273,
  serialized_end=4401,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /kms/v1/asymmetricEncryptionKeys:\001*\262\322*@\n%CreateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Get',
    index=1,
    containing_service=None,
    input_type=_GETASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricencryption_dot_asymmetric__encryption__key__pb2._ASYMMETRICENCRYPTIONKEY,
    serialized_options=b'\202\323\344\223\002+\022)/kms/v1/asymmetricEncryptionKeys/{key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.List',
    index=2,
    containing_service=None,
    input_type=_LISTASYMMETRICENCRYPTIONKEYSREQUEST,
    output_type=_LISTASYMMETRICENCRYPTIONKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /kms/v1/asymmetricEncryptionKeys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002.2)/kms/v1/asymmetricEncryptionKeys/{key_id}:\001*\262\322*@\n%UpdateAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEASYMMETRICENCRYPTIONKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+*)/kms/v1/asymmetricEncryptionKeys/{key_id}\262\322*@\n%DeleteAsymmetricEncryptionKeyMetadata\022\027AsymmetricEncryptionKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTASYMMETRICENCRYPTIONKEYOPERATIONSREQUEST,
    output_type=_LISTASYMMETRICENCRYPTIONKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/kms/v1/asymmetricEncryptionKeys/{key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/kms/v1/asymmetricEncryptionKeys/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E\"@/kms/v1/asymmetricEncryptionKeys/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/kms/v1/asymmetricEncryptionKeys/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASYMMETRICENCRYPTIONKEYSERVICE)

DESCRIPTOR.services_by_name['AsymmetricEncryptionKeyService'] = _ASYMMETRICENCRYPTIONKEYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto',
  package='yandex.cloud.kms.v1.asymmetricsignature',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nFyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_key.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x16\x41symmetricSignatureKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12[\n\x06labels\x18\x06 \x03(\x0b\x32K.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry\x12V\n\x06status\x18\x07 \x01(\x0e\x32\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status\x12\x62\n\x13signature_algorithm\x18\x08 \x01(\x0e\x32\x45.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03*\xda\x03\n\x1c\x41symmetricSignatureAlgorithm\x12.\n*ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_256\x10\x01\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_384\x10\x02\x12\x1d\n\x19RSA_2048_SIGN_PSS_SHA_512\x10\x03\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_256\x10\x04\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_384\x10\x05\x12\x1d\n\x19RSA_3072_SIGN_PSS_SHA_512\x10\x06\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_256\x10\x07\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_384\x10\x08\x12\x1d\n\x19RSA_4096_SIGN_PSS_SHA_512\x10\t\x12\x1b\n\x17\x45\x43\x44SA_NIST_P256_SHA_256\x10\n\x12\x1b\n\x17\x45\x43\x44SA_NIST_P384_SHA_384\x10\x0b\x12\x1b\n\x17\x45\x43\x44SA_NIST_P521_SHA_512\x10\x0c\x12\x1c\n\x18\x45\x43\x44SA_SECP256_K1_SHA_256\x10\rBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ASYMMETRICSIGNATUREALGORITHM = _descriptor.EnumDescriptor(
  name='AsymmetricSignatureAlgorithm',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_256', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_384', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_2048_SIGN_PSS_SHA_512', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_256', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_384', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_3072_SIGN_PSS_SHA_512', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_256', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_384', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RSA_4096_SIGN_PSS_SHA_512', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P256_SHA_256', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P384_SHA_384', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_NIST_P521_SHA_512', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ECDSA_SECP256_K1_SHA_256', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=721,
  serialized_end=1195,
)
_sym_db.RegisterEnumDescriptor(_ASYMMETRICSIGNATUREALGORITHM)

AsymmetricSignatureAlgorithm = enum_type_wrapper.EnumTypeWrapper(_ASYMMETRICSIGNATUREALGORITHM)
ASYMMETRIC_SIGNATURE_ALGORITHM_UNSPECIFIED = 0
RSA_2048_SIGN_PSS_SHA_256 = 1
RSA_2048_SIGN_PSS_SHA_384 = 2
RSA_2048_SIGN_PSS_SHA_512 = 3
RSA_3072_SIGN_PSS_SHA_256 = 4
RSA_3072_SIGN_PSS_SHA_384 = 5
RSA_3072_SIGN_PSS_SHA_512 = 6
RSA_4096_SIGN_PSS_SHA_256 = 7
RSA_4096_SIGN_PSS_SHA_384 = 8
RSA_4096_SIGN_PSS_SHA_512 = 9
ECDSA_NIST_P256_SHA_256 = 10
ECDSA_NIST_P384_SHA_384 = 11
ECDSA_NIST_P521_SHA_512 = 12
ECDSA_SECP256_K1_SHA_256 = 13


_ASYMMETRICSIGNATUREKEY_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=646,
  serialized_end=718,
)
_sym_db.RegisterEnumDescriptor(_ASYMMETRICSIGNATUREKEY_STATUS)


_ASYMMETRICSIGNATUREKEY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=644,
)

_ASYMMETRICSIGNATUREKEY = _descriptor.Descriptor(
  name='AsymmetricSignatureKey',
  full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature_algorithm', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.signature_algorithm', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletion_protection', full_name='yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.deletion_protection', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ASYMMETRICSIGNATUREKEY_LABELSENTRY, ],
  enum_types=[
    _ASYMMETRICSIGNATUREKEY_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=718,
)

_ASYMMETRICSIGNATUREKEY_LABELSENTRY.containing_type = _ASYMMETRICSIGNATUREKEY
_ASYMMETRICSIGNATUREKEY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASYMMETRICSIGNATUREKEY.fields_by_name['labels'].message_type = _ASYMMETRICSIGNATUREKEY_LABELSENTRY
_ASYMMETRICSIGNATUREKEY.fields_by_name['status'].enum_type = _ASYMMETRICSIGNATUREKEY_STATUS
_ASYMMETRICSIGNATUREKEY.fields_by_name['signature_algorithm'].enum_type = _ASYMMETRICSIGNATUREALGORITHM
_ASYMMETRICSIGNATUREKEY_STATUS.containing_type = _ASYMMETRICSIGNATUREKEY
DESCRIPTOR.message_types_by_name['AsymmetricSignatureKey'] = _ASYMMETRICSIGNATUREKEY
DESCRIPTOR.enum_types_by_name['AsymmetricSignatureAlgorithm'] = _ASYMMETRICSIGNATUREALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AsymmetricSignatureKey = _reflection.GeneratedProtocolMessageType('AsymmetricSignatureKey', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ASYMMETRICSIGNATUREKEY_LABELSENTRY,
    '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _ASYMMETRICSIGNATUREKEY,
  '__module__' : 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_key_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKey)
  })
_sym_db.RegisterMessage(AsymmetricSignatureKey)
_sym_db.RegisterMessage(AsymmetricSignatureKey.LabelsEntry)


DESCRIPTOR._options = None
_ASYMMETRICSIGNATUREKEY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
